;;; zenirc-me-away.el --- Sends away message to channels when you (un)set it

;; Copyright (C) 2004 Andrew Stribblehill

;; Author: Andrew Stribblehill <ads@debian.org>
;; Maintainer: ads@debian.org
;; Keywords: zenirc, away, extensions
;; Created: 2004-03-02

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation version 2
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program; if not, you can either send email to this
;; program's maintainer or write to: The Free Software Foundation,
;; Inc.; 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

;;; Commentary:

;;; Code:

(require 'zenirc)

(defvar zenirc-away-message "is away [%s]"
  "Message to send when you say you're away.")

(defvar zenirc-back-message "returns"
  "Message to send when you say you're back.")

;; /AWAY --- if invoked with arguments, you are away. Without arguments,
;; you are back.

;; Sends a message to that effect to each channel you are on and the
;; current victim (if not in your channel list).
(defun zenirc-say-away (proc parsed)
  (let* ((message (cdr parsed))
	 (fmessage (concat "\^AACTION "
		    (format (if (string= message "") zenirc-back-message
		       zenirc-away-message) message)
		    "\^A"))
	 (victims (if (member zenirc-current-victim zenirc-channel-list)
		      zenirc-channel-list
		    (cons zenirc-current-victim zenirc-channel-list))))
    (message "Victims: %s" victims)
    (mapc (lambda (victim)
	    (zenirc-send-multi-line
	     proc (concat "PRIVMSG " victim)
	     fmessage))
	  zenirc-channel-list)))

(zenirc-add-hook 'zenirc-command-away-hook 'zenirc-say-away)

(provide 'zenirc-me-away)
